==> mokkery-runtime-androidnativearm64-1.8.22-1.2.0-javadoc.jar: mokkery-runtime/dev.mokkery.answering/-blocking-sequential-answer-builder/index.md <==
//[mokkery-runtime](../../../index.md)/[dev.mokkery.answering](../index.md)/[BlockingSequentialAnswerBuilder](index.md)

# BlockingSequentialAnswerBuilder

[common]\
interface [BlockingSequentialAnswerBuilder](index.md)&lt;[T](index.md)&gt; : [BlockingAnsweringScope](../-blocking-answering-scope/index.md)&lt;[T](index.md)&gt; , [SequentialAnswerBuilder](../-sequential-answer-builder/index.md)&lt;[T](index.md)&gt; 

Marker interface for sequential answer builder for non-suspend function

## Functions

| Name | Summary |
|---|---|
| [answers](../-answering-scope/answers.md) | [common]<br>@DelicateMokkeryApi<br>abstract infix fun [answers](../-answering-scope/answers.md)(answer: [Answer](../-answer/index.md)&lt;[T](index.md)&gt;)<br>Registers given [answer](../-answering-scope/answers.md) for a function call. Direct usage requires care, because it allows to register suspending answer for non-suspend function. |
| [calls](../calls.md) | [common]<br>infix fun &lt;[T](../calls.md)&gt; [BlockingAnsweringScope](../-blocking-answering-scope/index.md)&lt;[T](../calls.md)&gt;.[calls](../calls.md)(block: ([FunctionScope](../-function-scope/index.md)) -&gt; [T](../calls.md))<br>Function call executes [block](../calls.md). |
| [repeat](../repeat.md) | [common]<br>fun &lt;[T](../repeat.md)&gt; [BlockingSequentialAnswerBuilder](index.md)&lt;[T](../repeat.md)&gt;.[repeat](../repeat.md)(block: [BlockingSequentialAnswerBuilder](index.md)&lt;[T](../repeat.md)&gt;.() -&gt; [Unit](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-unit/index.html)): [Nothing](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-nothing/index.html)<br>Allows to define a set of answers in [sequentially](../sequentially.md) that will repeat in cycles. |
| [returns](../returns.md) | [common]<br>infix fun &lt;[T](../returns.md)&gt; [AnsweringScope](../-answering-scope/index.md)&lt;[T](../returns.md)&gt;.[returns](../returns.md)(value: [T](../returns.md))<br>Function call always returns [value](../returns.md). |
| [sequentially](../sequentially.md) | [common]<br>infix fun &lt;[T](../sequentially.md)&gt; [BlockingAnsweringScope](../-blocking-answering-scope/index.md)&lt;[T](../sequentially.md)&gt;.[sequentially](../sequentially.md)(block: [BlockingSequentialAnswerBuilder](index.md)&lt;[T](../sequentially.md)&gt;.() -&gt; [Unit](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-unit/index.html))<br>Function call will answer sequentially with answers defined in [block](../sequentially.md). |
| [sequentiallyReturns](../sequentially-returns.md) | [common]<br>infix fun &lt;[T](../sequentially-returns.md)&gt; [AnsweringScope](../-answering-scope/index.md)&lt;[T](../sequentially-returns.md)&gt;.[sequentiallyReturns](../sequentially-returns.md)(values: [Iterable](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-iterable/index.html)&lt;[T](../sequentially-returns.md)&gt;)<br>Simplification for [sequentially](../sequentially.md) with multiple [returns](../returns.md) calls. |
| [sequentiallyThrows](../sequentially-throws.md) | [common]<br>infix fun &lt;[T](../sequentially-throws.md)&gt; [AnsweringScope](../-answering-scope/index.md)&lt;[T](../sequentially-throws.md)&gt;.[sequentiallyThrows](../sequentially-throws.md)(errors: [Iterable](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-iterable/index.html)&lt;[Throwable](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-throwable/index.html)&gt;)<br>Simplification for [sequentially](../sequentially.md) with multiple [throws](../throws.md) calls. |
| [throws](../throws.md) | [common]<br>infix fun &lt;[T](../throws.md)&gt; [AnsweringScope](../-answering-scope/index.md)&lt;[T](../throws.md)&gt;.[throws](../throws.md)(error: [Throwable](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-throwable/index.html))<br>Function call always throws [error](../throws.md). |

==> mokkery-runtime-androidnativearm64-1.9.0-1.1.0-javadoc.jar: mokkery-runtime/dev.mokkery.answering/-blocking-sequential-answer-builder/index.md <==
//[mokkery-runtime](../../../index.md)/[dev.mokkery.answering](../index.md)/[BlockingSequentialAnswerBuilder](index.md)

# BlockingSequentialAnswerBuilder

[common]\
interface [BlockingSequentialAnswerBuilder](index.md)&lt;[T](index.md)&gt; : [BlockingAnsweringScope](../-blocking-answering-scope/index.md)&lt;[T](index.md)&gt; , [SequentialAnswerBuilder](../-sequential-answer-builder/index.md)&lt;[T](index.md)&gt; 

Marker interface for sequential answer builder for non-suspend function

## Functions

| Name | Summary |
|---|---|
| [answers](../-answering-scope/answers.md) | [common]<br>@DelicateMokkeryApi<br>abstract fun [answers](../-answering-scope/answers.md)(answer: [Answer](../-answer/index.md)&lt;[T](index.md)&gt;)<br>Registers given [answer](../-answering-scope/answers.md) for a function call. Direct usage requires care, because it allows to register suspending answer for non-suspend function. |
| [calls](../calls.md) | [common]<br>infix fun &lt;[T](../calls.md)&gt; [BlockingAnsweringScope](../-blocking-answering-scope/index.md)&lt;[T](../calls.md)&gt;.[calls](../calls.md)(block: ([FunctionScope](../-function-scope/index.md)) -&gt; [T](../calls.md))<br>Function call executes [block](../calls.md). |
| [repeat](../repeat.md) | [common]<br>fun &lt;[T](../repeat.md)&gt; [BlockingSequentialAnswerBuilder](index.md)&lt;[T](../repeat.md)&gt;.[repeat](../repeat.md)(block: [BlockingSequentialAnswerBuilder](index.md)&lt;[T](../repeat.md)&gt;.() -&gt; [Unit](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-unit/index.html)): [Nothing](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-nothing/index.html)<br>Allows to define a set of answers in [sequentially](../sequentially.md) that will repeat in cycles. |
| [returns](../returns.md) | [common]<br>infix fun &lt;[T](../returns.md)&gt; [AnsweringScope](../-answering-scope/index.md)&lt;[T](../returns.md)&gt;.[returns](../returns.md)(value: [T](../returns.md))<br>Function call always returns [value](../returns.md). |
| [sequentially](../sequentially.md) | [common]<br>infix fun &lt;[T](../sequentially.md)&gt; [BlockingAnsweringScope](../-blocking-answering-scope/index.md)&lt;[T](../sequentially.md)&gt;.[sequentially](../sequentially.md)(block: [BlockingSequentialAnswerBuilder](index.md)&lt;[T](../sequentially.md)&gt;.() -&gt; [Unit](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-unit/index.html))<br>Function call will answer sequentially with answers defined in [block](../sequentially.md). |
| [sequentiallyReturns](../sequentially-returns.md) | [common]<br>infix fun &lt;[T](../sequentially-returns.md)&gt; [AnsweringScope](../-answering-scope/index.md)&lt;[T](../sequentially-returns.md)&gt;.[sequentiallyReturns](../sequentially-returns.md)(values: [Iterable](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-iterable/index.html)&lt;[T](../sequentially-returns.md)&gt;)<br>Simplification for [sequentially](../sequentially.md) with multiple [returns](../returns.md) calls. |
| [sequentiallyThrows](../sequentially-throws.md) | [common]<br>infix fun &lt;[T](../sequentially-throws.md)&gt; [AnsweringScope](../-answering-scope/index.md)&lt;[T](../sequentially-throws.md)&gt;.[sequentiallyThrows](../sequentially-throws.md)(errors: [Iterable](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-iterable/index.html)&lt;[Throwable](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-throwable/index.html)&gt;)<br>Simplification for [sequentially](../sequentially.md) with multiple [throws](../throws.md) calls. |
| [throws](../throws.md) | [common]<br>infix fun &lt;[T](../throws.md)&gt; [AnsweringScope](../-answering-scope/index.md)&lt;[T](../throws.md)&gt;.[throws](../throws.md)(error: [Throwable](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-throwable/index.html))<br>Function call always throws [error](../throws.md). |
